@@ -47,6 +47,8 @@ class Organization:
                  proxy: str = None):
         """Initialize an instance of organization."""
         # set debug and file if specified and let the calling application dictate logging handlers
+        self.log_file = log_file
+        self.debug = debug
         if logger:
             # print(f"using logger '{logger}' from param")
             self.logger = logger
@@ -56,11 +58,10 @@ class Organization:
 #        self.logger = logger or logging.getLogger(__name__)
             self.logger.addHandler(logging.NullHandler())
 
-        if debug:
-            self.debug = debug
+        if self.debug:
             self.logger.setLevel(logging.DEBUG)
-        if log_file:
-            self.log_file = log_file
+
+        if self.log_file:
             file_handler = logging.FileHandler(log_file, encoding='utf-8')
             formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s')
             formatter.converter = time.gmtime
@@ -571,7 +572,7 @@ path to credentials file.
         else:
             return(network_group)
 
-    def get_network(self, network_id: str, embed: str = None, accept: str = None):
+    def get_network(self, network_id: str, embed: object = None, accept: str = None):
         """Describe a Network by ID.
 
         :param str network_id: UUIDv4 of the network to get
@@ -583,16 +584,19 @@ path to credentials file.
         headers = dict()
         headers["authorization"] = "Bearer " + self.token
         params = dict()
-        if embed == "all":
-            params['embed'] = ', '.join(EMBED_NET_RESOURCES)
-            self.logger.debug(f"requesting embed all resource types in network domain: {params['embed']}")
-        elif embed:
-            valid_types = [plural(type) for type in embed.split(',') if RESOURCES[plural(type)]['domain'] == "network"]
-            params['embed'] = ', '.join(valid_types)
-            self.logger.debug(f"requesting embed some resource types in network domain: {valid_types}")
-            for type in embed.split(','):
-                if not NET_RESOURCES.get(type):
-                    self.logger.warn(f"not requesting '{type}', not a resource type in the network domain")
+        requested_types = list()
+        valid_types = set()
+        if embed:
+            if isinstance(embed, list):
+                requested_types.extend(embed)
+            else:
+                requested_types.extend(embed.split(','))
+            if 'all' in requested_types:
+                valid_types = ['all']
+            else:
+                valid_types = [plural(type) for type in requested_types if EMBED_NET_RESOURCES.get(plural(type))]
+            params['embed'] = ','.join(valid_types)
+            self.logger.debug(f"requesting embed of: '{valid_types}'")
 
         url = self.audience+'core/v2/networks/'+network_id
         network, status_symbol = get_generic_resource(url=url, headers=headers, accept=accept, proxies=self.proxies, verify=self.verify, **params)
